Pointcloud Module
=================

.. automodule:: pointcloud
   :members:
   
   .. autosummary::
      
      get_pointcloud_after_substracting_point_cloud
      pointcloud_audit
      pointcloud_sanitize
